@@ -27,7 +27,6 @@ enum jool_stat_id {
 	JSTAT_SKB_SHARED,
 	JSTAT_L3HDR_OFFSET,
 	JSTAT_SKB_TRUNCATED,
-	JSTAT_FRAGMENTED_PING,
 	JSTAT_HDR6,
 	JSTAT_HDR4,
 
@@ -66,6 +65,8 @@ enum jool_stat_id {
 	JSTAT64_ICMP_CSUM,
 	JSTAT64_UNTRANSLATABLE_PARAM_PROB_PTR,
 	JSTAT64_TTL,
+	JSTAT64_FRAGMENTED_ICMP,
+	JSTAT64_2XFRAG,
 	JSTAT64_FRAG_THEN_EXT,
 	JSTAT64_SEGMENTS_LEFT,
 
@@ -76,6 +77,7 @@ enum jool_stat_id {
 	JSTAT46_ICMP_CSUM,
 	JSTAT46_UNTRANSLATABLE_PARAM_PROBLEM_PTR,
 	JSTAT46_TTL,
+	JSTAT46_FRAGMENTED_ICMP,
 	JSTAT46_SRC_ROUTE,
 	JSTAT46_FRAGMENTED_ZERO_CSUM,
 	JSTAT46_BAD_MTU,
@@ -89,7 +91,6 @@ enum jool_stat_id {
 	JSTAT_ICMP4ERR_SUCCESS,
 	JSTAT_ICMP4ERR_FAILURE,
 
-	JSTAT_ICMPEXT_SMALL,
 	JSTAT_ICMPEXT_BIG,
 
 	/* These 3 need to be last, and in this order. */
